(prometheus-reporter
reg
{:keys [reporter-name push-gateway-url rate-unit duration-unit grouping-keys]
:or {rate-unit TimeUnit/SECONDS duration-unit TimeUnit/MILLISECONDS}
:as opts})(sanitize-grouping-key k)Prometheus does not like characters other than alpha-numeric and underscores. Replace every other character with _
Prometheus does not like characters other than alpha-numeric and underscores. Replace every other character with _
(sanitize-grouping-keys g)sanitize the key and the value of the grouping key map to prometheus friendly values
sanitize the key and the value of the grouping key map to prometheus friendly values
(start-reporting registry
{:keys [reporting-frequency-seconds host port prefix rate-unit
duration-unit]
:or {reporting-frequency-seconds 10
rate-unit TimeUnit/SECONDS
duration-unit TimeUnit/MILLISECONDS}
:as cfg})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |